from setuptools import setup

setup(
    name='CCPrint',
    version='0.1.3',
    description='a package to print colorful text in the console',
    url='https://github.com/Nico1806/CCPrint',
    author='Nico F.',
    author_email='nicofisseler@gmail.com',
    license='MIT',
    packages=['package'],
    classifiers=[
        'Programming Language :: Python :: 3.9',
    ],
)